package com.aucma.production.service;

import java.util.List;

import com.aucma.production.domain.ProdTeamShift;

public interface IProdTeamShiftService {
    ProdTeamShift selectProdTeamShiftByObjId(Long objId);

    List<ProdTeamShift> selectProdTeamShiftList(ProdTeamShift prodTeamShift);

    int insertProdTeamShift(ProdTeamShift prodTeamShift);

    int updateProdTeamShift(ProdTeamShift prodTeamShift);

    int deleteProdTeamShiftByObjIds(Long[] objIds);
}
