package com.aucma.production.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.aucma.common.annotation.Log;
import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.enums.BusinessType;
import com.aucma.production.domain.ProdTeamShift;
import com.aucma.production.service.IProdTeamShiftService;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.common.core.page.TableDataInfo;

@RestController
@RequestMapping("/production/teamShift")
public class ProdTeamShiftController extends BaseController {
    @Autowired
    private IProdTeamShiftService prodTeamShiftService;

    @PreAuthorize("@ss.hasPermi('production:teamShift:list')")
    @GetMapping("/list")
    public TableDataInfo list(ProdTeamShift prodTeamShift) {
        startPage();
        List<ProdTeamShift> list = prodTeamShiftService.selectProdTeamShiftList(prodTeamShift);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasPermi('production:teamShift:export')")
    @Log(title = "班组排班维护", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ProdTeamShift prodTeamShift) {
        List<ProdTeamShift> list = prodTeamShiftService.selectProdTeamShiftList(prodTeamShift);
        ExcelUtil<ProdTeamShift> util = new ExcelUtil<ProdTeamShift>(ProdTeamShift.class);
        util.exportExcel(response, list, "班组排班维护数据");
    }

    @PreAuthorize("@ss.hasPermi('production:teamShift:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId) {
        return success(prodTeamShiftService.selectProdTeamShiftByObjId(objId));
    }

    @PreAuthorize("@ss.hasPermi('production:teamShift:add')")
    @Log(title = "班组排班维护", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ProdTeamShift prodTeamShift) {
        prodTeamShift.setCreatedBy(getUsername());
        return toAjax(prodTeamShiftService.insertProdTeamShift(prodTeamShift));
    }

    @PreAuthorize("@ss.hasPermi('production:teamShift:edit')")
    @Log(title = "班组排班维护", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ProdTeamShift prodTeamShift) {
        prodTeamShift.setUpdatedBy(getUsername());
        return toAjax(prodTeamShiftService.updateProdTeamShift(prodTeamShift));
    }

    @PreAuthorize("@ss.hasPermi('production:teamShift:remove')")
    @Log(title = "班组排班维护", businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(prodTeamShiftService.deleteProdTeamShiftByObjIds(objIds));
    }
}
